Module cache_flush

Module cache_flush 

Structs

CacheFlushCapability
Runtime capability required for x86 cache-line eviction.
CacheFlushOnDrop
Clear-on-drop wrapper using volatile writes followed by checked x86_64 cache-line eviction.
CacheFlushReport
Successful cache-eviction outcome.

Enums

CacheFlushError
Why cache-line eviction could not be completed.

Traits

CacheFlushSanitize
Trait for values that should be cleared with volatile byte writes and then evicted from x86_64 cache lines when supported.

Functions

cache_flush_capability
Query the runtime cache-flush capability.
cache_flush_sanitize_array
Clear a fixed-size byte array with volatile writes, then flush its cache lines.
cache_flush_sanitize_bytes
Clear a mutable byte slice with volatile writes, then flush its cache lines.
cache_flush_sanitize_string
Clear a String allocation capacity with volatile writes, then flush the cache lines covering the allocation.
cache_flush_sanitize_vec
Clear a Vec<u8> allocation capacity with volatile writes, then flush the cache lines covering the allocation.
flush_cache_lines
Flush the cache lines covering a byte slice.