CacheFlushOnDrop

Struct CacheFlushOnDrop 

pub struct CacheFlushOnDrop<T: CacheFlushSanitize> { /* private fields */ }
Clear-on-drop wrapper using volatile writes followed by x86_64 cache line eviction.

Implementations

Source

impl<T: CacheFlushSanitize> CacheFlushOnDrop<T>

pub const fn new(inner: T) -> Self

Wrap a value that implements CacheFlushSanitize.

pub fn with_secret<R>(&self, inspect: impl FnOnce(&T) -> R) -> R

Run a closure with read-only access to the wrapped value.

pub fn with_secret_mut<R>(&mut self, edit: impl FnOnce(&mut T) -> R) -> R

Run a closure with mutable access to the wrapped value.

pub fn into_cleared(self)

Consume the wrapper after first clearing and flushing the wrapped value.