Structs
- Cache
Flush Capability - Runtime capability required for x86 cache-line eviction.
- Cache
Flush OnDrop - Clear-on-drop wrapper using volatile writes followed by checked x86_64 cache-line eviction.
- Cache
Flush Report - Successful cache-eviction outcome.
Enums
- Cache
Flush Error - Why cache-line eviction could not be completed.
Traits
- Cache
Flush Sanitize - Trait for values that should be cleared with volatile byte writes and then evicted from x86_64 cache lines when supported.
Functions
- cache_
flush_ capability - Query the runtime cache-flush capability.
- cache_
flush_ sanitize_ array - Clear a fixed-size byte array with volatile writes, then flush its cache lines.
- cache_
flush_ sanitize_ bytes - Clear a mutable byte slice with volatile writes, then flush its cache lines.
- cache_
flush_ sanitize_ string - Clear a
Stringallocation capacity with volatile writes, then flush the cache lines covering the allocation. - cache_
flush_ sanitize_ vec - Clear a
Vec<u8>allocation capacity with volatile writes, then flush the cache lines covering the allocation. - flush_
cache_ lines - Flush the cache lines covering a byte slice.